@@ -22,6 +22,18 @@ FSCK_LOGFILE=/var/log/fsck/checkroot
 . /lib/lsb/init-functions
 . /lib/init/mount-functions.sh
 
+_want_force_fsck () {
+	case "$(findmnt -n -o FSTYPE /)" in
+	# Only ext* file systems support `-f' option to fsck. See #686895
+	(ext*)
+		[ -f /forcefsck ] || grep -q -s -w -i "forcefsck" /proc/cmdline
+		;;
+	(*)
+		return 1
+		;;
+	esac
+}
+
 do_start () {
 	# Trap SIGINT so that we can handle user interrupt of fsck.
 	trap "" INT
@@ -203,12 +215,8 @@ Will restart in 5 seconds."
 	#
 	if [ "$rootcheck" = yes ]
 	then
-		if [ -f /forcefsck ] || grep -q -s -w -i "forcefsck" /proc/cmdline
-		then
-			force="-f"
-		else
-			force=""
-		fi
+		force=""
+		_want_force_fsck && force="-f"
 
 		if [ "$FSCKFIX" = yes ]
 		then
@@ -231,7 +239,7 @@ Will restart in 5 seconds."
 		if [ "$VERBOSE" = no ]
 		then
 			log_action_begin_msg "Checking root file system"
-			logsave -s $FSCK_LOGFILE fsck $spinner $force $fix -t $roottype $rootdev
+			logsave_best_effort fsck $spinner $force $fix -t $roottype $rootdev
 			FSCKCODE=$?
 			if [ "$FSCKCODE" = 0 ]
 			then
@@ -241,7 +249,7 @@ Will restart in 5 seconds."
 			fi
 		else
 			log_daemon_msg "Will now check root file system"
-			logsave -s $FSCK_LOGFILE fsck $spinner $force $fix -V -t $roottype $rootdev
+			logsave_best_effort fsck $spinner $force $fix -V -t $roottype $rootdev
 			FSCKCODE=$?
 			log_end_msg $FSCKCODE
 		fi
