@@ -436,7 +436,7 @@ post_mountall ()
 	# directory.  The migration logic will then take care of the
 	# rest.  Note that it will take a second boot to fully
 	# migrate; it should only ever be needed on broken systems.
-	RAMSHM_ON_DEV_SHM="no"
+	RAMSHM_ON_DEV_SHM="yes"
 	if read_fstab_entry "/dev/shm"; then
 	    RAMSHM_ON_DEV_SHM="yes"
 	fi
@@ -559,8 +559,8 @@ mount_shm ()
 {
 	MNTMODE="$1"
 
-	RAMSHM_ON_DEV_SHM="no"
-	SHMDIR="/run/shm"
+	RAMSHM_ON_DEV_SHM="yes"
+	SHMDIR="/dev/shm"
 	if read_fstab_entry "/dev/shm"; then
 		if [ "$MNTMODE" = "mount_noupdate" ]; then
 			log_warning_msg "Warning: fstab entry for /dev/shm; should probably be for /run/shm unless working around a bug in the Oracle database"
